@@ -4,6 +4,7 @@ from django.conf import settings
 PROFILE_APP_NAME = None
 PROFILE_MODEL_NAME = None
 COMMENT_PROFILE_API_FIELDS = []
+COMMENT_USER_API_FIELDS = ['id', 'username', 'email']
 
 COMMENT_USE_GRAVATAR = False
 
@@ -26,3 +27,9 @@ COMMENT_ANONYMOUS_USERNAME = 'Anonymous User'
 COMMENT_USE_EMAIL_FIRST_PART_AS_USERNAME = False
 
 COMMENT_ALLOW_TRANSLATION = False
+
+COMMENT_ALLOW_SUBSCRIPTION = False
+
+COMMENT_ORDER_BY = ['-posted']
+
+COMMENT_WRAP_CONTENT_WORDS = 30
