@@ -1,10 +1,12 @@
 from collections import namedtuple
 
 from django.db import models, IntegrityError
-from django.conf import settings
 from django.core.exceptions import ValidationError, ObjectDoesNotExist
 from django.utils.translation import gettext_lazy as _
 
+from comment.conf import settings
+from comment.messages import FlagError
+
 
 class FlagManager(models.Manager):
     def get_for_comment(self, comment):
@@ -17,10 +19,7 @@ class FlagManager(models.Manager):
 
 class FlagInstanceManager(models.Manager):
 
-    REASONS = getattr(settings, 'COMMENT_FLAG_REASONS', [
-        (1, _('Spam | Exists only to promote a service')),
-        (2, _('Abusive | Intended at promoting hatred')),
-    ])
+    REASONS = getattr(settings, 'COMMENT_FLAG_REASONS')
     REASONS.append((100, _('Something else')))
 
     Reason = namedtuple('Reason', ['value', 'reason'])
@@ -31,11 +30,7 @@ class FlagInstanceManager(models.Manager):
     reason_values = [reason.value for reason in reasons_list]
 
     def _clean_reason(self, reason):
-        err = ValidationError(
-                _('%(reason)s is an invalid reason'),
-                params={'reason': reason},
-                code='invalid'
-                )
+        err = ValidationError(FlagError.REASON_INVALID.format(reason=reason), code='invalid')
         try:
             reason = int(reason)
             if reason in self.reason_values:
@@ -52,19 +47,11 @@ class FlagInstanceManager(models.Manager):
         if cleaned_reason == self.reason_values[-1]:
             cleaned_info = info
             if not cleaned_info:
-                raise ValidationError(
-                    _('Please supply some information as the reason for flagging'),
-                    params={'info': info},
-                    code='required'
-                )
+                raise ValidationError(FlagError.INFO_MISSING, code='required')
         return cleaned_reason, cleaned_info
 
     def create_flag(self, user, flag, reason, info):
-        err = ValidationError(
-            _('This comment is already flagged by this user (%(user)s)'),
-            params={'user': user},
-            code='invalid'
-        )
+        err = ValidationError(FlagError.ALREADY_FLAGGED_BY_USER.format(user=user), code='invalid')
         cleaned_reason, cleaned_info = self._clean(reason, info)
         try:
             self.create(flag=flag, user=user, reason=cleaned_reason, info=cleaned_info)
@@ -72,11 +59,7 @@ class FlagInstanceManager(models.Manager):
             raise err
 
     def delete_flag(self, user, flag):
-        err = ValidationError(
-            _('This comment was not flagged by this user (%(user)s)'),
-            params={'user': user},
-            code='invalid'
-        )
+        err = ValidationError(FlagError.NOT_FLAGGED_BY_USER.format(user=user), code='invalid')
         try:
             self.get(user=user, flag=flag).delete()
         except self.model.DoesNotExist:
