@@ -5,6 +5,15 @@ class ErrorMessage:
     LOGIN_URL_MISSING = _('Comment App: LOGIN_URL is not in the settings')
     METHOD_NOT_IMPLEMENTED = _('Your {class_name} class has not defined a {method_name} method, which is required.')
     NON_AJAX_REQUEST = _('Only AJAX request are allowed')
+    INVALID_ORDER_ARGUMENT = _((
+        'Comment app: "{order}" is not a valid value for COMMENT_ORDER_BY. '
+        'Please choose one among {allowed_orders}.'
+        ))
+    DUPLICATE_ORDER_VALUE = _((
+        'Comment app: COMMENT_ORDER_BY should not have duplicated values '
+        'Duplicated Values: {duplicates}. Please use one value only E.g. "{order}" or "-{order}".'
+    ))
+    WRAP_CONTENT_WORDS_NOT_INT = _('Comment App: settings var COMMENT_WRAP_CONTENT_WORDS must be an integer')
 
 
 class ExceptionError:
@@ -34,6 +43,7 @@ class FlagError:
     NOT_FLAGGED_BY_USER = _('This comment was not flagged by this user ({user})')
     REJECT_UNFLAGGED_COMMENT = _('This action cannot be applied on unflagged comments')
     RESOLVE_UNEDITED_COMMENT = _('The comment must be edited before resolving the flag')
+    STATE_CHANGE_ERROR = _('Unable to change flag state at the moment!')
 
 
 class ReactionError:
@@ -41,6 +51,7 @@ class ReactionError:
 
 
 class EmailError:
+    EMAIL_INVALID = _('Enter a valid email address.')
     EMAIL_MISSING = _('Email is required for posting anonymous comments.')
     BROKEN_VERIFICATION_LINK = _('The link seems to be broken.')
     USED_VERIFICATION_LINK = _('The comment has already been verified.')
@@ -56,11 +67,12 @@ class ReactionInfo:
 
 
 class EmailInfo:
-    SUBJECT = _('Comment Confirmation Request')
+    CONFIRMATION_SUBJECT = _('Comment Confirmation Request')
     CONFIRMATION_SENT = _('We have sent a verification link to your email.'
                           'The comment will be displayed after it is verified.')
     INPUT_PLACEHOLDER = _('email address, this will be used for verification.')
     INPUT_TITLE = _('email address, it will be used for verification.')
+    NOTIFICATION_SUBJECT = _('{username} added comment to "{thread_name}"')
     LABEL = _('email')
 
 
@@ -69,3 +81,8 @@ class FlagState:
     FLAGGED = _('Flagged')
     REJECTED = _('Flag rejected by the moderator')
     RESOLVED = _('Comment modified by the author')
+
+
+class FollowError:
+    EMAIL_REQUIRED = _('Email is required to subscribe {model_object}')
+    SYSTEM_NOT_ENABLED = _('Subscribe system must be enabled')
