@@ -33,10 +33,12 @@ class Comment(models.Model):
         ordering = ['-posted', ]
 
     def __str__(self):
+        username = self.get_username()
+        _content = self.content[:20]
         if not self.parent:
-            return f'comment by {self.user}: {self.content[:20]}'
+            return f'comment by {username}: {_content}'
         else:
-            return f'reply by {self.user}: {self.content[:20]}'
+            return f'reply by {username}: {_content}'
 
     def __repr__(self):
         return self.__str__()
@@ -57,9 +59,13 @@ class Comment(models.Model):
         return getattr(self.reaction, reaction_type, None)
 
     def replies(self, include_flagged=False):
+        manager = self.__class__.objects
         if include_flagged:
-            return self.__class__.objects.filter(parent=self).order_by('posted')
-        return self.__class__.objects.all_exclude_flagged().filter(parent=self).order_by('posted')
+            qs = manager.all()
+        else:
+            qs = manager.all_exclude_flagged()
+
+        return manager._filter_parents(qs, parent=self)
 
     def _set_unique_urlhash(self):
         if not self.urlhash:
@@ -69,7 +75,20 @@ class Comment(models.Model):
 
     def _set_email(self):
         if self.user:
-            self.email = self.user.email
+            self.email = getattr(self.user, self.user.EMAIL_FIELD, '')
+
+    def _get_username_for_anonymous(self):
+        if settings.COMMENT_USE_EMAIL_FIRST_PART_AS_USERNAME:
+            return self.email.split('@')[0]
+
+        return settings.COMMENT_ANONYMOUS_USERNAME
+
+    def get_username(self):
+        user = self.user
+        if not user:
+            return self._get_username_for_anonymous()
+
+        return getattr(user, user.USERNAME_FIELD)
 
     def save(self, *args, **kwargs):
         self._set_unique_urlhash()
