@@ -5,26 +5,33 @@ document.addEventListener('DOMContentLoaded', () => {
     'use strict';
     let currentDeleteCommentButton, commentBeforeEdit;
     let csrfToken = window.CSRF_TOKEN;
+    let deleteModal = document.getElementById("Modal");
+    let flagModal = document.getElementById('flagModal');
+    let followModal = document.getElementById('followModal');
     let headers = {
         'X-Requested-With': 'XMLHttpRequest',
         'X-CSRFToken': csrfToken,
         'Content-Type': 'application/x-www-form-urlencoded'
     };
     document.getElementsByClassName(".js-comment-input").value = '';
-    let removeTargetElement = e => {
+    let removeTargetElement = () => {
         let currentHeight = window.pageYOffset;
         window.location.replace("#");
         // slice off the remaining '#':
         if (typeof window.history.replaceState == 'function') {
             history.replaceState({}, '', window.location.href.slice(0, -1));
         }
-            window.scrollTo(0, currentHeight);
-        }
+        window.scrollTo(0, currentHeight);
+        // close three-dots-menus
+        Array.prototype.forEach.call(document.getElementsByClassName('js-three-dots-menu'), element => {
+            element.classList.add('d-none');
+        });
+    };
 
     let showModal = modalElement => {
         modalElement.style.display = 'block';
         setTimeout(() => {
-          modalElement.classList.add('show-modal');
+            modalElement.classList.add('show-modal');
         }, 20);
     };
 
@@ -46,11 +53,11 @@ document.addEventListener('DOMContentLoaded', () => {
         if (textarea.value.replace(/^\s+|\s+$/g, "").length === 0) {
             textarea.setAttribute("style", "height: 31px;");
             if (commentButton) {
-               commentButton.setAttribute('disabled', 'disabled');
+                commentButton.setAttribute('disabled', 'disabled');
             }
         } else {
             if (commentButton) {
-               commentButton.removeAttribute('disabled');
+                commentButton.removeAttribute('disabled');
             }
         }
 
@@ -99,42 +106,51 @@ document.addEventListener('DOMContentLoaded', () => {
 
     let convertFormDataToURLQuery = formData => {
         return Object.keys(formData).map((key) => {
-          return encodeURIComponent(key) + '=' + encodeURIComponent(formData[key]);
+            return encodeURIComponent(key) + '=' + encodeURIComponent(formData[key]);
         }).join('&');
     };
 
     // create new comment
     let submitCommentCreateForm = form => {
+        let errorElement = form.querySelector('.error');
+        if (!errorElement.classList.contains('d-none')) errorElement.classList.add('d-none');
         let formButton = form.querySelector("button");
         let url = form.getAttribute('data-url') || window.location.href;
+        const urlParams = new window.URLSearchParams(window.location.search);
         let formData = serializeObject(form);
+        formData.page = urlParams.get('page');
         // this step is needed to append the form data to request.POST
         let formDataQuery = convertFormDataToURLQuery(formData);
         fetch(url, {
-           method: 'POST',
+            method: 'POST',
             headers: headers,
             body: formDataQuery
         }).then(response => {
-            if (response.status === 200) {
-                return response.text();
-            }
-            else if (response.status === 400) {
-                return response.json();
-            }
-            return Promise.reject(response);
-        }).then(data => {
-            if (data.type === 'error') {
-                console.log(data);
-                alert(data.detail);
+            return response.json();
+        }).then(result => {
+            if (result.error) {
+                // alert(result.error);
+                form.querySelector('.error').innerHTML = result.error;
+                form.querySelector('.error').classList.remove('d-none');
                 return;
             }
-           // parent comment
+            // parent comment
             if (formButton.getAttribute('value') === 'parent') {
                 // reload all comments only when posting parent comment
-                document.getElementById("comments").outerHTML = data;
+                if (result.anonymous) {
+                    createInfoElement(form.closest('.js-comment'), 'success', result.msg, 3);
+                    form.reset();
+                    return;
+                }
+                document.getElementById("comments").outerHTML = result.data;
             } else {
                 // child comment
-                let childComment = stringToDom(data, '.js-child-comment');
+                if (result.anonymous) {
+                    createInfoElement(form.closest('.js-parent-comment'), 'success', result.msg, 3);
+                    form.reset();
+                    return;
+                }
+                let childComment = stringToDom(result.data, '.js-child-comment');
                 form.parentNode.insertBefore(childComment, form);
                 // update number of replies
                 let reply = form.parentElement.previousElementSibling.querySelector(".js-reply-link");
@@ -147,6 +163,10 @@ document.addEventListener('DOMContentLoaded', () => {
                     reply.textContent = gettext("Reply");
                 }
                 commentCount(1);
+                // update followBtn
+                let followButton = form.parentElement.previousElementSibling.querySelector(".js-comment-follow");
+                followButton.querySelector('.comment-follow-icon').classList.add('user-has-followed');
+                followButton.querySelector('span').setAttribute('title', 'Unfollow this thread');
             }
             formButton.setAttribute('disabled', 'disabled');
             let elements = document.getElementsByClassName("js-comment-input");
@@ -160,7 +180,7 @@ document.addEventListener('DOMContentLoaded', () => {
                 let clean_uri = uri.substring(0, uri.indexOf("?"));
                 window.history.replaceState({}, document.title, clean_uri);
             }
-        }).catch(error => {
+        }).catch(() => {
             alert(gettext("Unable to post your comment!, please try again"));
         });
     };
@@ -170,9 +190,9 @@ document.addEventListener('DOMContentLoaded', () => {
         commentBeforeEdit = commentContent; // store old comment
         let url = editButton.getAttribute('href');
         fetch(url, {headers: headers}).then(response => {
-            return response.text();
-        }).then(data => {
-            let editModeElement = stringToDom(data, '.js-comment-update-mode');
+            return response.json();
+        }).then(result => {
+            let editModeElement = stringToDom(result.data, '.js-comment-update-mode');
             commentContent.replaceWith(editModeElement);
             // set the focus on the end of text
             let value = document.querySelector(".js-comment-edit-form").querySelector('textarea').value;
@@ -181,7 +201,7 @@ document.addEventListener('DOMContentLoaded', () => {
             textAreaElement.value = '';
             textAreaElement.value = value;
             textAreaElement.setAttribute("style", "height: " + textAreaElement.scrollHeight + "px;");
-        }).catch(error => {
+        }).catch(() => {
             alert(gettext("You can't edit this comment"));
         });
     };
@@ -196,16 +216,16 @@ document.addEventListener('DOMContentLoaded', () => {
 
         let formDataQuery = convertFormDataToURLQuery(formData);
         fetch(url, {
-           method: 'POST',
+            method: 'POST',
             headers: headers,
             body: formDataQuery
         }).then(response => {
-            return response.text();
-        }).then(data => {
-           let updatedContentElement = stringToDom(data, '.js-updated-comment');
-           form.parentElement.replaceWith(updatedContentElement);
-        }).catch(error => {
-           alert(gettext("Modification didn't take effect!, please try again"));
+            return response.json();
+        }).then(result => {
+            let updatedContentElement = stringToDom(result.data, '.js-updated-comment');
+            form.parentElement.replaceWith(updatedContentElement);
+        }).catch(() => {
+            alert(gettext("Modification didn't take effect!, please try again"));
         });
     };
 
@@ -223,8 +243,8 @@ document.addEventListener('DOMContentLoaded', () => {
 
     let getParentByClassName = (element, className) => {
         let parents = getParents(element);
-        for (let i=0; i<parents.length; i++) {
-            if (parents[i].classList.contains(className)){
+        for (let i = 0; i < parents.length; i++) {
+            if (parents[i].classList.contains(className)) {
                 return parents[i];
             }
         }
@@ -233,8 +253,8 @@ document.addEventListener('DOMContentLoaded', () => {
 
     let getNthParent = (element, nth) => {
         let parents = getParents(element);
-        if (parents.length >= nth){
-            return parents[nth-1];
+        if (parents.length >= nth) {
+            return parents[nth - 1];
         }
     };
 
@@ -244,17 +264,16 @@ document.addEventListener('DOMContentLoaded', () => {
         let url = deleteBtn.getAttribute('data-url');
         fetch(url, {headers: headers}).then(response => {
             return response.json()
-        }).then(data => {
-            let modal = document.getElementById("Modal");
-            showModal(modal);
-            let modalContent = modal.querySelector('.comment-modal-content');
-            modalContent.innerHTML = data.html_form;
-        }).catch(error => {
-            console.error(error);
+        }).then(result => {
+            showModal(deleteModal);
+            let modalContent = deleteModal.querySelector('.comment-modal-content');
+            modalContent.innerHTML = result.data;
+        }).catch(() => {
+            alert(gettext("Deletion cannot be performed!, please try again"));
         });
     };
 
-    let submitDeleteCommentForm = form =>{
+    let submitDeleteCommentForm = form => {
         let commentElement = getNthParent(currentDeleteCommentButton, 5);
         let formData = serializeObject(form);
         let url = form.getAttribute("data-url");
@@ -266,16 +285,15 @@ document.addEventListener('DOMContentLoaded', () => {
 
         let formDataQuery = convertFormDataToURLQuery(formData);
         fetch(url, {
-           method: 'POST',
+            method: 'POST',
             headers: headers,
             body: formDataQuery
         }).then(response => {
-            return response.text();
-        }).then(data => {
+            return response.json();
+        }).then(result => {
             if (isParent) {
-                document.getElementById("comments").outerHTML = data;
-            }
-            else {
+                document.getElementById("comments").outerHTML = result.data;
+            } else {
                 // update replies count if a child was deleted
                 let replyNumberElement = getParentByClassName(commentElement, 'js-parent-comment').querySelector(".js-reply-number");
                 let replyLinkElement = getParentByClassName(commentElement, 'js-parent-comment').querySelector(".js-reply-link");
@@ -290,11 +308,9 @@ document.addEventListener('DOMContentLoaded', () => {
                 // update total count of comments
                 commentCount(-1);
             }
-            let modal = document.getElementById("Modal");
-            hideModal(modal);
+            hideModal(deleteModal);
             commentElement.remove();
-
-        }).catch(error => {
+        }).catch(() => {
             alert(gettext("Unable to delete your comment!, please try again"));
         });
     };
@@ -341,23 +357,71 @@ document.addEventListener('DOMContentLoaded', () => {
         let parentReactionEle = reactionButton.parentElement;
         let url = reactionButton.getAttribute('href');
         fetch(url, {
-           method: 'POST',
+            method: 'POST',
             headers: headers
-           }).then(response => {
-                return response.json();
-            }).then(data => {
-                let status = data.status;
+        }).then(response => {
+            return response.json();
+        }).then(result => {
+            if (result.error) {
+                alert(result.error);
+            } else {
+                let status = result.data.status;
                 if (status === 0) {
                     fillReaction(parentReactionEle, targetReaction);
-                    changeReactionCount(parentReactionEle, data.likes, data.dislikes);
+                    changeReactionCount(parentReactionEle, result.data.likes, result.data.dislikes);
                 }
-            }).catch(error => {
-                alert(gettext("Reaction couldn't be processed!, please try again"));
-            });
-        };
+            }
+        }).catch(() => {
+            alert(gettext("Reaction couldn't be processed!, please try again"));
+        });
+    };
+
+    let toggleFollow = (followButton, form) => {
+        let formDataQuery = null;
+        if (form) {
+            let formData = serializeObject(form);
+            formDataQuery = convertFormDataToURLQuery(formData);
+        }
+        let url = followButton.getAttribute('data-url');
+        fetch(url, {
+            method: 'POST',
+            headers: headers,
+            body: formDataQuery,
+        }).then(response => {
+            return response.json();
+        }).then(result => {
+            if (result.error) {
+                if (result.error.email_required) {
+                    followModal.querySelector('form').setAttribute('data-target-btn-id', followButton.getAttribute('id'));
+                    showModal(followModal);
+                } else if (result.error.invalid_email) {
+                    form.querySelector('.error').innerHTML = result.error.invalid_email;
+                }
+            } else if (result.data) {
+                const infoElement = result.data.app_name === 'comment'
+                    ? followButton.closest('.js-parent-comment')
+                    : document.getElementById('comments').querySelector('.js-comment');
+                if (result.data.following) {
+                    followButton.querySelector('.comment-follow-icon').classList.add('user-has-followed');
+                    followButton.querySelector('span').setAttribute('title', 'Unfollow this thread');
+                    const msg = gettext(`You are now subscribing "${result.data.model_object}"`);
+                    createInfoElement(infoElement, 'success', msg);
+                    hideModal(followModal);
+                } else {
+                    followButton.querySelector('.comment-follow-icon').classList.remove('user-has-followed');
+                    followButton.querySelector('span').setAttribute('title', 'Follow this thread');
+                    const msg = gettext(`"${result.data.model_object}" is now unsubscribed`);
+                    createInfoElement(infoElement, 'success', msg);
+                    hideModal(followModal);
+                }
+            }
+        }).catch(() => {
+            alert(gettext("Subscription couldn't be processed!, please try again"));
+        });
+    };
 
     let fadeOut = (element, duration) => {
-      let interval = 10;//ms
+        let interval = 10;  //ms
         let opacity = 1.0;
         let targetOpacity = 0.0;
         let timer = setInterval(() => {
@@ -366,12 +430,12 @@ document.addEventListener('DOMContentLoaded', () => {
                 clearInterval(timer);
             }
             element.style.opacity = opacity;
-            opacity -= 1.0/((1000/interval)*duration);
+            opacity -= 1.0 / ((1000 / interval) * duration);
         }, interval);
     };
 
     let fadeIn = (element, duration) => {
-        let interval = 10;//ms
+        let interval = 10;  //ms
         let opacity = 0.0;
         let targetOpacity = 1.0;
         let timer = setInterval(() => {
@@ -380,7 +444,7 @@ document.addEventListener('DOMContentLoaded', () => {
                 clearInterval(timer);
             }
             element.style.opacity = opacity;
-            opacity += 1.0/((1000/interval)*duration);
+            opacity += 1.0 / ((1000 / interval) * duration);
         }, interval);
     };
 
@@ -404,9 +468,9 @@ document.addEventListener('DOMContentLoaded', () => {
         temp.innerHTML = msg;
         responseEle.prepend(temp);
         fixToTop(temp);
-        fadeIn(temp, duration );
-        setTimeout(() =>{
-          fadeOut(temp, duration);
+        fadeIn(temp, duration);
+        setTimeout(() => {
+            fadeOut(temp, duration);
         }, duration * 1500);
 
         setTimeout(() => {
@@ -414,60 +478,60 @@ document.addEventListener('DOMContentLoaded', () => {
         }, 2500 * duration);
     };
 
-     let fixToTop = div => {
+    let fixToTop = div => {
         let top = 200;
         let isFixed = div.style.position === 'fixed';
-        if (div.scrollTop > top && !isFixed){
-           div.setAttribute('style', "{'position': 'fixed', 'top': '0px'}");
+        if (div.scrollTop > top && !isFixed) {
+            div.setAttribute('style', "{'position': 'fixed', 'top': '0px'}");
         }
         if (div.scrollTop < top && isFixed) {
-           div.setAttribute('style', "{'position': 'static', 'top': '0px'}");
+            div.setAttribute('style', "{'position': 'static', 'top': '0px'}");
         }
     };
 
-    let submitFlagForm = (flagButton, reason=null, info=null) => {
+    let submitFlagForm = (flagButton, reason = null, info = null) => {
         let formData = {};
-        if (reason){
+        if (reason) {
             formData['reason'] = reason;
         }
-        if (info){
+        if (info) {
             formData['info'] = info;
         }
         let url = flagButton.getAttribute('data-url');
 
         let formDataQuery = convertFormDataToURLQuery(formData);
         fetch(url, {
-           method: 'POST',
+            method: 'POST',
             headers: headers,
             body: formDataQuery
         }).then(response => {
             return response.json();
-        }).then(data => {
-            let addClass = 'user-has-flagged';
-            let removeClass = 'user-has-not-flagged';
-            let flagIcon = flagButton.querySelector('.comment-flag-icon');
-            if (data.flag === 1) {
-                flagIcon.parentElement.title = 'Remove flag';
-                toggleClass(flagIcon, addClass, removeClass, 'add');
+        }).then(result => {
+            if (result.error) {
+                alert(result.error)
             } else {
-                flagIcon.parentElement.title = 'Report Comment';
-                toggleClass(flagIcon, addClass, removeClass, 'remove');
+                let addClass = 'user-has-flagged';
+                let removeClass = 'user-has-not-flagged';
+                let flagIcon = flagButton.querySelector('.comment-flag-icon');
+                if (result.data.flag === 1) {
+                    flagIcon.parentElement.title = 'Remove flag';
+                    toggleClass(flagIcon, addClass, removeClass, 'add');
+                } else {
+                    flagIcon.parentElement.title = 'Report Comment';
+                    toggleClass(flagIcon, addClass, removeClass, 'remove');
+                }
+                hideModal(flagModal);
+                createInfoElement(flagButton.closest('.js-parent-comment'), result.data.status, result.msg);
             }
-            let modal = document.getElementById('flagModal');
-            hideModal(modal);
-            if (data) {
-                createInfoElement(flagButton.closest('.js-parent-comment'), data.status, data.msg);
-            }
-        }).catch(error => {
+        }).catch(() => {
             alert(gettext("Flagging couldn't be processed!, please try again"));
         });
     };
 
     let handleFlagModal = flagButton => {
-        let modal = document.getElementById('flagModal');
-        showModal(modal);
-        document.getElementById('flagModal').querySelector('textarea').value = '';
-        let form = modal.querySelector('.flag-modal-form');
+        showModal(flagModal);
+        flagModal.querySelector('textarea').value = '';
+        let form = flagModal.querySelector('.flag-modal-form');
         let lastReason = form.querySelector('.flag-last-reason');
         let flagInfo = form.querySelector('textarea');
         flagInfo.style.display = "none";
@@ -484,7 +548,7 @@ document.addEventListener('DOMContentLoaded', () => {
                 }
             });
         };
-        let submit = modal.querySelector('.flag-modal-submit');
+        let submit = flagModal.querySelector('.flag-modal-submit');
         submit.onclick = e => {
             e.preventDefault();
             let choice = form.querySelector('input[name="reason"]:checked');
@@ -505,9 +569,9 @@ document.addEventListener('DOMContentLoaded', () => {
     const toggleText = readMoreButton => {
         readMoreButton.previousElementSibling.classList.toggle('d-none');
         if (readMoreButton.previousElementSibling.classList.contains('d-none')) {
-           readMoreButton.innerHTML = gettext("read more ...");
+            readMoreButton.innerHTML = gettext("read more ...");
         } else {
-           readMoreButton.innerHTML = gettext("read less");
+            readMoreButton.innerHTML = gettext("read less");
         }
     };
 
@@ -520,13 +584,14 @@ document.addEventListener('DOMContentLoaded', () => {
 
         let formDataQuery = convertFormDataToURLQuery(formData);
         fetch(url, {
-           method: 'POST',
+            method: 'POST',
             headers: headers,
             body: formDataQuery
         }).then(response => {
             return response.json();
-        }).then(data => {
-            if (data.state === 0) {
+        }).then(result => {
+            if (result.error) {
+                alert(result.error);
                 return;
             }
             let commentBodyElement = getNthParent(changeStateButton, 3);
@@ -538,9 +603,9 @@ document.addEventListener('DOMContentLoaded', () => {
                     ? gettext('Flag rejected')
                     : gettext('Reject the flag');
                 const contentModifiedBtn = changeStateButton.parentElement.querySelector('.js-flag-resolve');
-                if (data.state === 3) {
+                if (result.data.state === 3) {
                     if (contentModifiedBtn) {
-                       contentModifiedBtn.firstElementChild.classList.remove("flag-resolved");
+                        contentModifiedBtn.firstElementChild.classList.remove("flag-resolved");
                         contentModifiedBtn.setAttribute('title', gettext('Resolve the flag'));
                     }
                     commentBodyElement.classList.remove('flagged-comment');
@@ -551,7 +616,7 @@ document.addEventListener('DOMContentLoaded', () => {
                     ? gettext('Flag resolved')
                     : gettext('Resolve the flag');
                 let rejectBtn = changeStateButton.parentElement.querySelector('.js-flag-reject');
-                if (data.state === 4) {
+                if (result.data.state === 4) {
                     if (rejectBtn) {
                         rejectBtn.firstElementChild.classList.remove("flag-rejected");
                         rejectBtn.setAttribute('title', gettext('Reject the flag'));
@@ -563,48 +628,49 @@ document.addEventListener('DOMContentLoaded', () => {
         });
     };
 
+    let openThreeDostMenu = threeDotBtn => {
+        threeDotBtn.nextElementSibling.classList.toggle('d-none');
+    };
+
     document.addEventListener('click', (event) => {
-        removeTargetElement(event);
+        removeTargetElement();
         if (event.target && event.target !== event.currentTarget) {
-            let modal = document.getElementById("Modal");
-            let flagModal = document.getElementById('flagModal');
-           if (event.target === modal || event.target === flagModal ||
-               event.target.closest('.modal-close-btn') || event.target.closest('.modal-cancel-btn')) {
-               hideModal(modal);
-               hideModal(flagModal)
-           }
-           else if(event.target.closest('.js-reply-link')) {
-               event.preventDefault();
-               replyLink(event.target);
-           }
-           else if (event.target.closest('.js-comment-edit')) {
-               event.preventDefault();
-               setCommentForEditMode(event.target.closest('.js-comment-edit'));
-           }
-           else if (event.target.closest('.js-comment-cancel')) {
-               event.preventDefault();
-               cancelEdit(event.target.closest('.js-comment-cancel'));
-           }
-           else if (event.target.closest('.js-comment-delete')) {
-               event.preventDefault();
-               loadForm(event.target.closest('.js-comment-delete'));
-           }
-           else if (event.target.closest('.js-comment-reaction')) {
-               event.preventDefault();
-               submitReaction(event.target.closest('.js-comment-reaction'));
-           }
-           else if (event.target.closest('.js-comment-flag')) {
-               event.preventDefault();
-               setFlag(event.target.closest('.js-comment-flag'));
-           }
-           else if (event.target.closest('.js-read-more-btn')) {
-               event.preventDefault();
-               toggleText(event.target);
-           }
-           else if (event.target.closest('.js-flag-reject') || event.target.closest('.js-flag-resolve')) {
-               event.preventDefault();
-               toggleFlagState(event.target.closest('.js-flag-reject') || event.target.closest('.js-flag-resolve'));
-           }
+            if (event.target === deleteModal || event.target === flagModal || event.target === followModal ||
+                event.target.closest('.modal-close-btn') || event.target.closest('.modal-cancel-btn')) {
+                hideModal(deleteModal);
+                hideModal(flagModal);
+                hideModal(followModal);
+            } else if (event.target.closest('.js-reply-link')) {
+                event.preventDefault();
+                replyLink(event.target);
+            } else if (event.target.closest('.js-comment-edit')) {
+                event.preventDefault();
+                setCommentForEditMode(event.target.closest('.js-comment-edit'));
+            } else if (event.target.closest('.js-comment-cancel')) {
+                event.preventDefault();
+                cancelEdit(event.target.closest('.js-comment-cancel'));
+            } else if (event.target.closest('.js-comment-delete')) {
+                event.preventDefault();
+                loadForm(event.target.closest('.js-comment-delete'));
+            } else if (event.target.closest('.js-comment-reaction')) {
+                event.preventDefault();
+                submitReaction(event.target.closest('.js-comment-reaction'));
+            } else if (event.target.closest('.js-comment-flag')) {
+                event.preventDefault();
+                setFlag(event.target.closest('.js-comment-flag'));
+            } else if (event.target.closest('.js-read-more-btn')) {
+                event.preventDefault();
+                toggleText(event.target);
+            } else if (event.target.closest('.js-flag-reject') || event.target.closest('.js-flag-resolve')) {
+                event.preventDefault();
+                toggleFlagState(event.target.closest('.js-flag-reject') || event.target.closest('.js-flag-resolve'));
+            } else if (event.target.closest('.js-comment-follow')) {
+                event.preventDefault();
+                toggleFollow(event.target.closest('.js-comment-follow'));
+            } else if (event.target.closest('.js-three-dots')) {
+                event.preventDefault();
+                openThreeDostMenu(event.target.closest('.js-three-dots'));
+            }
         }
     }, false);
 
@@ -615,14 +681,16 @@ document.addEventListener('DOMContentLoaded', () => {
                 if (event.target.querySelector('.js-comment-input').value.replace(/^\s+|\s+$/g, "").length !== 0) {
                     submitCommentCreateForm(event.target);
                 }
-            }
-            else if (event.target.classList.contains('js-comment-edit-form')) {
+            } else if (event.target.classList.contains('js-comment-edit-form')) {
                 event.preventDefault();
                 submitEditCommentForm(event.target);
-            }
-            else if (event.target.classList.contains('js-comment-delete-form')) {
+            } else if (event.target.classList.contains('js-comment-delete-form')) {
                 event.preventDefault();
                 submitDeleteCommentForm(event.target);
+            } else if (event.target.classList.contains('js-comment-follow-form')) {
+                event.preventDefault();
+                let followButton = document.getElementById(event.target.getAttribute('data-target-btn-id'));
+                toggleFollow(followButton, event.target);
             }
         }
     }, false);
@@ -634,8 +702,7 @@ document.addEventListener('DOMContentLoaded', () => {
             let editForm = event.target.closest('.js-comment-edit-form');
             if (createForm && createForm.querySelector('.js-comment-input').value.replace(/^\s+|\s+$/g, "").length !== 0) {
                 submitCommentCreateForm(createForm);
-            }
-            else if (editForm && editForm.querySelector('.js-comment-input').value.replace(/^\s+|\s+$/g, "").length !== 0) {
+            } else if (editForm && editForm.querySelector('.js-comment-input').value.replace(/^\s+|\s+$/g, "").length !== 0) {
                 submitEditCommentForm(editForm);
             }
         }
