@@ -1,14 +1,18 @@
+import re
+
 from django import template
 
-from comment.models import ReactionInstance, FlagInstance
+from comment.models import ReactionInstance, FlagInstance, Follower
 from comment.forms import CommentForm
 from comment.utils import (
-    get_comment_context_data, is_comment_moderator, is_comment_admin, get_gravatar_img, get_profile_instance
+    is_comment_moderator, is_comment_admin, get_gravatar_img, get_profile_instance, get_wrapped_words_number
 )
 from comment.managers import FlagInstanceManager
-from comment.conf import settings
 from comment.messages import ReactionError
+from comment.context import DABContext
 
+MULTIPLE_NEW_LINE_RE = re.compile(r'(.*)(\n){2,}(.*)')
+SINGLE_NEW_LINE_RE = re.compile(r'(.*)(\n)(.*)')
 register = template.Library()
 
 
@@ -26,11 +30,7 @@ def get_app_name(obj):
 
 @register.simple_tag(name='get_username_for_comment')
 def get_username_for_comment(comment):
-    if not comment.user:
-        if settings.COMMENT_USE_EMAIL_FIRST_PART_AS_USERNAME:
-            return comment.email.split('@')[0]
-        return settings.COMMENT_ANONYMOUS_USERNAME
-    return comment.user.username
+    return comment.get_username()
 
 
 @register.simple_tag(name='get_profile_url')
@@ -75,7 +75,7 @@ def render_comments(obj, request, oauth=False):
     """
     Retrieves list of comment related to a certain object and renders the appropriate template
     """
-    context = get_comment_context_data(request, model_object=obj)
+    context = DABContext(request, model_object=obj)
     context.update({
         'comment_form': CommentForm(request=request),
         'oauth': oauth
@@ -86,9 +86,15 @@ def render_comments(obj, request, oauth=False):
 register.inclusion_tag('comment/base.html')(render_comments)
 
 
-def render_content(comment, number):
-    number = int(number)
-    content = comment.content
+def render_content(comment, number=None):
+    try:
+        number = int(number)
+    except (ValueError, TypeError):
+        number = get_wrapped_words_number()
+
+    # Restrict 2 or more line breaks to 2 <br>
+    content = MULTIPLE_NEW_LINE_RE.sub(r'\1<br><br>\3', comment.content)
+    content = SINGLE_NEW_LINE_RE.sub(r'\1<br>\3', content)
     content_words = content.split()
     if not number or len(content_words) <= number:
         text_1 = content
@@ -158,6 +164,13 @@ def has_flagged(user, comment):
     return False
 
 
+@register.filter(name='has_followed')
+def has_followed(user, model_object):
+    if user.is_authenticated:
+        return Follower.objects.is_following(user.email, model_object)
+    return False
+
+
 @register.simple_tag(name='render_flag_reasons')
 def render_flag_reasons():
     return FlagInstanceManager.reasons_list
