@@ -1,5 +1,3 @@
-from comment.conf import settings
-from comment.signals import adjust_flagged_comments
 from comment.tests.base import BaseCommentMigrationTest
 
 
