@@ -37,9 +37,9 @@ class CommentTemplateTagsTest(BaseTemplateTagsTest):
         self.assertEqual(url, '/static/img/default.png')
 
         # missing profile
-        patch.object(settings, 'PROFILE_MODEL_NAME', None).start()
-        url = get_profile_url(self.parent_comment_1)
-        self.assertEqual(url, '/static/img/default.png')
+        with patch.object(settings, 'PROFILE_MODEL_NAME', None):
+            url = get_profile_url(self.parent_comment_1)
+            self.assertEqual(url, '/static/img/default.png')
 
     @patch.object(settings, 'COMMENT_USE_GRAVATAR', False)
     def test_get_img_path(self):
@@ -47,25 +47,23 @@ class CommentTemplateTagsTest(BaseTemplateTagsTest):
         self.assertNotEqual(url, '/static/img/default.png')
 
         # use default pic on fail
-        patch.object(settings, 'PROFILE_MODEL_NAME', 'app not exist').start()
-        url = get_img_path(self.parent_comment_1)
-        self.assertEqual(url, '/static/img/default.png')
+        with patch.object(settings, 'PROFILE_MODEL_NAME', 'app not exist'):
+            url = get_img_path(self.parent_comment_1)
+            self.assertEqual(url, '/static/img/default.png')
 
-        patch.object(settings, 'PROFILE_APP_NAME', 'user_profile').start()
-        patch('comment.templatetags.comment_tags.get_profile_instance', return_value=None).start()
-        url = get_img_path(self.parent_comment_1)
-        self.assertEqual(url, '/static/img/default.png')
+        with patch.object(settings, 'PROFILE_APP_NAME', 'user_profile'):
+            with patch('comment.templatetags.comment_tags.get_profile_instance', return_value=None):
+                url = get_img_path(self.parent_comment_1)
+                self.assertEqual(url, '/static/img/default.png')
 
     @patch.object(settings, 'PROFILE_APP_NAME', 'user_profile')
     @patch.object(settings, 'COMMENT_USE_GRAVATAR', False)
     def test_profile_has_no_image_field(self):
-        mocked_hasattr = patch('comment.templatetags.comment_tags.hasattr').start()
-        mocked_hasattr.return_value = False
-        url = get_img_path(self.parent_comment_1)
-        self.assertEqual(url, '/static/img/default.png')
+        with patch('comment.templatetags.comment_tags.hasattr', return_value=False):
+            url = get_img_path(self.parent_comment_1)
+            self.assertEqual(url, '/static/img/default.png')
 
     def test_render_comments(self):
-        current_login_url = getattr(settings, 'LOGIN_URL', '/profile/login/')
         request = self.factory.get('/')
         request.user = self.user_1
         comments_per_page = 'COMMENT_PER_PAGE'
@@ -77,20 +75,21 @@ class CommentTemplateTagsTest(BaseTemplateTagsTest):
         self.assertEqual(data['comments'].count(), count)  # parent comment only
         self.assertEqual(data['login_url'], settings.LOGIN_URL)
 
-        # LOGIN_URL is not provided
-        patch.object(settings, 'LOGIN_URL', None).start()
+    @patch.object(settings, 'LOGIN_URL', None)
+    def test_render_comments_without_login_url(self):
+        request = self.factory.get('/')
+        request.user = self.user_1
         with self.assertRaises(ImproperlyConfigured) as error:
             render_comments(self.post_1, request)
         self.assertIsInstance(error.exception, ImproperlyConfigured)
 
-        # check pagination
-        patch.object(settings, comments_per_page, 2).start()
-        patch.object(settings, 'LOGIN_URL', current_login_url).start()
+    @patch.object(settings, 'COMMENT_PER_PAGE', 2)
+    def test_render_comments_with_pagination(self):
         request = self.factory.get('/?page=2')
         request.user = self.user_1
         data = render_comments(self.post_1, request)
 
-        self.assertTrue(data['comments'].has_previous())
+        self.assertIs(data['comments'].has_previous(), True)
         self.assertEqual(data['comments'].paginator.per_page, 2)  # 2 comment per page
         self.assertEqual(data['comments'].number, 2)  # 3 comment fit in 2 pages
         self.assertEqual(data['login_url'], settings.LOGIN_URL)
@@ -99,13 +98,13 @@ class CommentTemplateTagsTest(BaseTemplateTagsTest):
         request = self.factory.get('/?page=string')
         request.user = self.user_1
         data = render_comments(self.post_1, request)
-        self.assertFalse(data['comments'].has_previous())
+        self.assertIs(data['comments'].has_previous(), False)
 
         # check empty page
         request = self.factory.get('/?page=10')
         request.user = self.user_1
         data = render_comments(self.post_1, request)
-        self.assertTrue(data['comments'].has_previous())
+        self.assertIs(data['comments'].has_previous(), True)
 
     def test_static_functions(self):
         self.assertEqual(include_static(), '')
@@ -120,6 +119,7 @@ class CommentTemplateTagsTest(BaseTemplateTagsTest):
             field = render_field(field, placeholder='placeholder')
             self.assertEqual(field.field.widget.attrs.get('placeholder'), 'placeholder')
 
+    @patch.object(settings, 'COMMENT_WRAP_CONTENT_WORDS', 10)
     def test_render_content(self):
         comment = self.parent_comment_1
         content = "Any long text just for testing render content function"
@@ -128,27 +128,68 @@ class CommentTemplateTagsTest(BaseTemplateTagsTest):
         content_words = comment.content.split()
         self.assertEqual(len(content_words), len(content.split()))
 
-        result = render_content(comment, 10)
+        result = render_content(comment)
         # test urlhash
         self.assertEqual(result['urlhash'], comment.urlhash)
         # truncate number is bigger than content words
         self.assertEqual(result['text_1'], comment.content)
         self.assertIsNone(result['text_2'])
-        # truncate number is smaller than content words
+
+    def test_single_line_breaks_in_render_content(self):
+        comment = self.parent_comment_1
+        comment.content = "Any long text\njust for testing render\ncontent function"
+
+        result = render_content(comment)
+
+        self.assertIn('<br>', result['text_1'])
+        self.assertNotIn('<br><br>', result['text_1'])
+
+    def test_multiple_line_breaks_in_render_content(self):
+        comment = self.parent_comment_1
+        comment.content = "Any long text\n\njust for testing render\n\n\ncontent function"
+
+        result = render_content(comment)
+
+        self.assertIn('<br><br>', result['text_1'])
+        self.assertNotIn('<br><br><br>', result['text_1'])
+
+    def test_render_content_with_passing_value(self):
+        comment = self.parent_comment_1
+        content = "Any long text just for testing render content function"
+        comment.content = content
+        comment.save()
+        content_words = comment.content.split()
+        self.assertEqual(len(content_words), len(content.split()))
+
         result = render_content(comment, 5)
+        # test urlhash
+        self.assertEqual(result['urlhash'], comment.urlhash)
+        # truncate number is smaller than content words
         self.assertEqual(result['text_1'], ' '.join(content_words[:5]))
         self.assertEqual(result['text_2'], ' '.join(content_words[5:]))
 
-    def test_get_username_for_comment(self):
+    @patch.object(settings, 'COMMENT_USE_EMAIL_FIRST_PART_AS_USERNAME', True)
+    def test_get_username_for_comment_use_email_first_part_enabled(self):
         comment = self.create_comment(self.content_object_1, user=self.user_1)
-        anonymous_comment = self.create_anonymous_comment()
 
         self.assertEqual(get_username_for_comment(comment), comment.user.username)
-        self.assertEqual(get_username_for_comment(anonymous_comment), settings.COMMENT_ANONYMOUS_USERNAME)
 
-        patch.object(settings, 'COMMENT_USE_EMAIL_FIRST_PART_AS_USERNAME', True).start()
+        # test for anonymous
+        anonymous_comment = self.create_anonymous_comment()
+
         self.assertEqual(get_username_for_comment(anonymous_comment), anonymous_comment.email.split('@')[0])
 
+    @patch.object(settings, 'COMMENT_USE_EMAIL_FIRST_PART_AS_USERNAME', False)
+    def test_get_username_for_comment_use_email_first_part_disabled(self):
+        comment = self.create_comment(self.content_object_1, user=self.user_1)
+
+        self.assertEqual(get_username_for_comment(comment), comment.user.username)
+
+        # test for anonymous
+        anonymous_comment = self.create_anonymous_comment()
+
+        self.assertEqual(get_username_for_comment(anonymous_comment), settings.COMMENT_ANONYMOUS_USERNAME)
+
 
 class ReactionTemplateTagsTest(BaseTemplateTagsTest):
     def setUp(self):
